enhance_widget library

Classes

EnBottomNavigationBar
修改: 官方 BottomNavigationBar 不支持 onDoubleTap,新增 ValueChanged<int>? onDoubleTap; 新增: tileBuilder,方便根据选中状态自定义
EnBoxDecoration
An immutable description of how to paint a box.
EnDecorationImage
修改: 新增 destinationOffset 属性 An image for a box decoration.
EnExpandIcon
A widget representing a rotating expand/collapse button. The icon rotates 180 degrees when pressed, then reverts the animation on a second press. The underlying icon is Icons.expand_more.
EnExpandListView<E>
custom: Expand List view
EnExpansionPanel
EnExpansionPanelList
A material expansion panel list that lays out its children and animates expansions.
EnExpansionPanelRadio
An expansion panel that allows for radio-like functionality. This means that at any given time, at most, one EnExpansionPanelRadio can remain expanded.
EnExpansionTile
A single-line ListTile with an expansion arrow icon that expands or collapses the tile to reveal or hide the children.
EnStep
A material step used in Stepper. The step can have a title and subtitle, an icon within its circle, some content and a state that governs its styling.
EnStepper
A material stepper widget that displays progress through a sequence of steps. Steppers are particularly useful in the case of forms where one step requires the completion of another one, or where multiple steps need to be completed in order to submit the whole form.
ExpandPanelModel<E>

Enums

EnExpansionPanelArrowPosition
HorizontalLinePosition
Defines the Stepper's separator position when the type is StepperType.horizontal.
HorizontalTitlePosition
Defines the Stepper's titles position when the type is StepperType.horizontal.

Functions

debugFlushLastFrameImageSizeInfo() → void
Flushes inter-frame tracking of image size information from paintImage.

Typedefs

ExpansionWidgetBuilder = Widget Function(bool isExpanded, VoidCallback onToggle)
EnExpansionTile 部分子组件构建类型