A widget representing a rotating expand/collapse button. The icon rotates
180 degrees when pressed, then reverts the animation on a second press.
The underlying icon is Icons.expand_more.
An expansion panel that allows for radio-like functionality.
This means that at any given time, at most, one EnExpansionPanelRadio
can remain expanded.
A material stepper widget that displays progress through a sequence of
steps. Steppers are particularly useful in the case of forms where one step
requires the completion of another one, or where multiple steps need to be
completed in order to submit the whole form.